      subroutine getheight(itime,xt,yt,zt,pt,ht)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE GETHEIGHT                   *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1994-04-07                                 *
*                                                                     * 
***********************************************************************
*                                                                     *
* DESCRIPTION: This subroutine calculates pressure [Pa] and geometric *
*              height [m] along trajectory for a given vertical       *
*              coordinate zt (eta ECMWF) on a given position (xt,yt). *
*                                                                     *
***********************************************************************
*                                                                     *
* INPUT:                                                              *
*                                                                     *
* itime     time relative to beginning of calculation period          *
* xt        x coordinate of point [grid units]                        *
* yt        y coordinate of point [grid units]                        *
* zt        z coordinate of point [units]                             *
*                                                                     *
***********************************************************************
*                                                                     *
* OUTPUT:                                                             *
*                                                                     *
* pt        pressure [Pa]                                             *
* ht        geometric height [m]                                      *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer i,itime,ihelp,index

      real pp,xt,yt,zt,pt,ht,psint
*
* SEE WHICH FIELDS ARE NEEDED FOR INTERPOLATION
*

      do 10 i=1,numbwf

         if(wftime(i)*ldirect.ge.itime*ldirect) goto 15

10    continue

15    if(i.eq.1) then
         ihelp=1
      else
         ihelp=i-1
      endif
*
* needed times for interpolation: wftime(ihelp),wftime(ihelp+1)
*

            
*
* LOOK IF FIELD IS ACTUALLY IN MEMORY
* IF YES: INTERPOLATION IS DONE
* IF NO:  EXECUTION IS STOPPED --> ERROR
*
      do 30 i=1,3

         if (memtime(i).eq.wftime (ihelp)) goto 40

30    continue

      stop 'SUBROUTINE GETHEIGHT: FATAL ERROR '

40    index=i
      
      if(index.ge.3) then

      stop 'SUBROUTINE GETHEIGHT: FATAL ERROR '
                               
      endif

      call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +xt,yt,1,memtime(index),memtime(index+1),itime,index,psint)

      pt=pp(psint,zt)

      call zztrafo(xt,yt,zt,memtime(index),memtime(index+1),itime,
     &             index,psint,ht)

      return
      end
