      subroutine getpv (itime,xt,yt,zt, pvt,theta)
C                         i   i  i  i    o    o
C
C     Calculation of the potential vorticiy (PV) on an isentropic surface
C
C     Author: Petra Seibert
C     Date: 27 April 1995 - 3 May 1995
C     corrected: 27 June 1996 (PS)
C
C     Variables:
C
C     itime [s}  	current temporal position
C     xt,yt,zt          current spatial position 
C     pvt		potential vorticity at trajectory location
C     pv                potential vorticity on subgrid
C     u,v		uu and vv on subgrid
C     theta             potential temperature at trajectory location
C
C     NOTE: in this subroutine the standard implicit type declaration
C           for real and integer (i-n) variables is used! 

      include 'includepar'
      include 'includecom'

      integer itime,index,n,ixt,jyt,iyj,jj,ixi,ii,ntime,kk,k,i,j,k0
      integer indz1,indz2
      real xt,yt,zt,pvt,theta,yj,xi,zijn,thijn,psij,vijn,uijn,u,v
      real dudy,dvdx,pv,pvint,rdz,stabil,phi,tanphi,cosphi,f
      real z,p,th,stab,dthetadp

      dimension pv(2,2,2), u(4,4), v(4,4), stab(2), stabil(4,4),
     &          p(4), th(4), z(4)
 
C     determine integer trajectory position
      ixt = int(xt)
      jyt = int(yt)
      if (ixt-1 .lt. 0 .or. ixt+2 .gt. nx-1 .or.
     &    jyt-1 .lt. 0 .or. jyt+2 .gt. ny-1) goto 900


C  Determine the times of the wind fields needed for interpolation

      if ( (ldirect*memtime(1) .lt. ldirect*itime) .and.
     &     (ldirect*memtime(2) .ge. ldirect*itime) ) then ! between 1st and 2nd
        index=1
      else if ( (ldirect*memtime(2) .lt. ldirect*itime) .and. 
     &     (ldirect*memtime(3) .ge. ldirect*itime) ) then ! between 2nd and 3rd
        index=2
      endif


C     determine potential temperature theta at trajectory position
      call potlininterpol (tt,ps,nxmax,nymax,nuvzmax,nx,ny,nuvz,
     &  memind,uvheight,akz,bkz,xt,yt,zt,memtime(index),
     &  memtime(index+1),itime,index,  theta )
 
C     determine parameters for time level before and after actual
      do 100 ntime = 1,2
        if (ntime .eq. 1) then
          n = index
        else 
          n = index+1
        endif

C       determine wind components on large subgrid

        do 40 jj = 1,4
          iyj = jyt + (jj-2) 
          yj = float( iyj ) 

          do 30 ii = 1,4
            ixi = ixt + (ii-2)
            xi = float ( ixi )

C           skip corners which are not needed
 
C           get vertical position zijn at (i,j,n)
C           use zt as first guess

            zijn = zt
            thijn = theta
            psij = ps( ixi, iyj, 1, memind(n) )
            call geteta (xi,yj,zijn,thijn,memtime(index),
     &         memtime(index+1),memtime(n),index,psij,indz1,indz2)
            if (indz1-1 .lt. 1 .or. indz1+2 .gt. nuvz) goto 900

C           check on unstable stratification => PV = 0.
            if (indz1 .ne. indz2) then
              stabil(ii,jj) = 0.
              goto 30
            endif

C           interpolate uu and vv vertically on large subgrid
            call lininterpol 
     &           (uu,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     &            xi,yj,zijn,memtime(index),memtime(index+1),
     &            memtime(n),index,uijn)
            u(ii,jj) = uijn 

            call lininterpol 
     &           (vv,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     &            xi,yj,zijn,memtime(index),memtime(index+1),
     &            memtime(n),index,vijn)
            v(ii,jj) = vijn

C           vertical loop to determine parameters needed for
C           stability calculation
            do 50 k = 1,4
              kk = indz1 - 1 + k-1
              z(k) = uvheight(kk)
              p(k) = akz(kk) + bkz(kk) * ps(ixi,iyj,1,memind(n))
              th(k) = tt(ixi,iyj,kk,memind(n)) * 
     &                 ( 100000./ p(k) )**kappa
50          continue

C           compute some relevant parameters
            rdz =  (zijn - z(2)) / (z(3) - z(2))
            if (rdz .lt. 0.5) then
              k0 = 0
            else
              k0 = 1
            endif
C           calculate stability
            do 60 k = 1,2
              kk = k0 + k
              stab(k) = (th(kk+1) - th(kk)) / (p(kk+1) - p(kk))
60          continue
            stabil(ii,jj) = stab(1) + (stab(2) - stab(1)) * rdz 

30        continue
40      continue

C     determine PV on small subgrid

        do 80 j = 1,2
          yj = float( jyt + j - 1 )
          jj = j + 1

          phi = (xlat0 + yj * dy) * pi / 180.
          tanphi = tan(phi)
          cosphi = cos(phi)
          f = 0.00014585 * sin(phi)

          do 70 i = 1,2
            ii = i + 1
 
C           calculate PV on spherical co-ordinates
C           Pichler, Dymanik der Atmosphaere, p. 193

            dthetadp = 0.14 * stabil(1+i,1+j) +
     &       0.125 * (stabil(1+i,j)+stabil(2+i,1+j)+
     &                stabil(1+i,2+j)+stabil(i,1+j)) +
     &       0.09* (stabil(i,j)+stabil(i,2+j)+
     &                stabil(2+j,2+j)+stabil(2+i,j))
 
            dudy = (u(ii,jj+1) - u(ii,jj-1)) * dyradinv * 0.5
            dvdx = (v(ii+1,jj) - v(ii-1,jj)) * dxradinv * 0.5

            pv(i,j,ntime) = dthetadp * 
     &        ( f + ( dvdx/cosphi - dudy + u(ii,jj)*tanphi ) / r_earth )

70        continue
80      continue
100   continue                

C     interpolate PV horizontally and in time

      call pvinterpol (pv, xt-ixt,yt-jyt,
     &       memtime(index),memtime(index+1),itime, pvint)

C     scale PV to PV units
      pvt =  pvint * -1.e6 * 9.81
      return

C     PV cannot be calculated because trajectory is too close to
C     boundaries of domain
900   pvt = -99.999
      return

      end
