      subroutine gridcheck(oronew,error)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE GRIDCHECK                   *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1997-08-06                                 *
*                                                                     * 
***********************************************************************
*                                                                     *
* DESCRIPTION:                                                        *
*                                                                     *
* THIS SUBROUTINE DETERMINES THE GRID SPECIFICATIONS (LOWER LEFT      *
* LONGITUDE, LOWER LEFT LATITUDE, NUMBER OF GRID POINTS, GRID DIST-   *
* ANCE AND VERTICAL DISCRETIZATION OF THE ECMWF MODEL) FROM THE       *
* GRIB HEADER OF THE FIRST INPUT FILE. THE CONSISTANCY (NO CHANGES    *
* WITHIN ONE FLEXTRA RUN) IS CHECKED IN THE ROUTINE "READWIND" AT ANY *
* CALL.                                                               *
*                                                                     *
* OUTPUT       error .true.   - can not read grid specifications      *
*              error .false.  - normal                                *
*              oronew .true.  - Terrain heights given in grib files   *
*              oronew .false. - Terrain heights not specified in the  *
*                               grib files (old file standard)        *
*                                                                     * 
* XLON0                geographical longitude of lower left gridpoint *
* XLAT0                geographical latitude of lower left gridpoint  *
* NX                   number of grid points x-direction              *
* NY                   number of grid points y-direction              *
* DX                   grid distance x-direction                      *
* DY                   grid distance y-direction                      *
* NUVZ                 number of grid points for horizontal wind      *
*                      components in z direction                      *
* NWZ                  number of grid points for vertical wind        *
*                      component in z direction                       *
* UVHEIGHT(1)-         heights of gridpoints where u and v are        *
* UVHEIGHT(NUVZ)       given                                          *
* WHEIGHT(1)-          heights of gridpoints where w is given         *
* WHEIGHT(NWZ)                                                        *
*                                                                     *
***********************************************************************
*
      include 'includepar'
      include 'includecom'

      integer i,ifn,ifield,j,k,iumax,iwmax,numskip
      real xhelp1,xhelp2,yhelp1,yhelp2
      logical error,oronew

* VARIABLES AND ARRAYS NEEDED FOR GRIB DECODING

      integer isec0(2),isec1(56),isec2(512),isec3(2),isec4(64)
      integer inbuff(jpack),ilen,ierr,iword,lunit
      real zsec2(128),zsec3(2),zsec4(jpunp)
      character*1 yoper,opt
      data yoper/'D'/

      error=.false.
      oronew=.false.
      iumax=0
      iwmax=0
*
      if(ideltas.gt.0) then
        ifn=1
      else
        ifn=numbwf
      endif
*
* OPENING OF DATA FILE (GRIB CODE)
*
5     call pbopen_(lunit,path(2)(1:len(2))//wfname(ifn),'r',ierr)
      if(ierr.lt.0) goto 999

      ifield=0   
10    ifield=ifield+1
*
* GET NEXT FIELDS
*
      call pbgrib(lunit,inbuff,jpack,ilen,ierr)
      if(ierr.eq.-1) goto 30    ! EOF DETECTED
      if(ierr.lt.-1) goto 999   ! ERROR DETECTED
 
      ierr=1
      call gribex(isec0,isec1,isec2,zsec2,isec3,zsec3,isec4,
     &            zsec4,jpunp,inbuff,jpack,iword,yoper,ierr)
      if (ierr.ne.0) goto 999   ! ERROR DETECTED

      if(ifield.eq.1) then
        nx=isec2(2)
        ny=isec2(3)
        xhelp1=float(isec2(5))/1000.
        xhelp2=float(isec2(8))/1000.
        if(xhelp1.gt.180) xhelp1=xhelp1-360.0
        if(xhelp2.gt.180) xhelp2=xhelp2-360.0
        if(xhelp1.lt.-180) xhelp1=xhelp1+360.0
        if(xhelp2.lt.-180) xhelp2=xhelp2+360.0
        yhelp1=float(isec2(7))/1000.
        yhelp2=float(isec2(4))/1000.
        xlon0=xhelp1
        xlat0=yhelp1
        dx=(xhelp2-xhelp1)/float(nx-1)
        dy=(yhelp2-yhelp1)/float(ny-1)
        nlev_ec=isec2(12)/2-1
      endif
     
      if(isec1(6).eq.129) oronew=.true.
      k=isec1(8)
      if(isec1(6).eq.131) iumax=max(iumax,nlev_ec-k+1)
      if(isec1(6).eq.135) iwmax=max(iwmax,nlev_ec-k+1) 

      if(isec1(6).eq.129) then
        do 20 i=0,nx-1
          do 20 j=0,ny-1
20          oro(i,j)=zsec4(nx*(ny-j-1)+i+1)/ga
      endif

      goto 10                      !! READ NEXT LEVEL OR PARAMETER
*
* CLOSING OF INPUT DATA FILE
*
30    call pbclose_(lunit,ierr)     !! FINNISHED READING / CLOSING GRIB FILE

      nuvz=iumax
      nwz =iwmax
      if(nuvz.eq.nlev_ec) nwz=nlev_ec+1

      if (nx.gt.nxmax) then                         
      write(*,*) 'Trajectory  model error: Too many grid points'//
     &           ' in x direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      endif

      if (ny.gt.nymax) then                         
      write(*,*) 'FLEXTRA error: Too many grid points in y direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      endif

      if (nuvz.gt.nuvzmax) then                         
      write(*,*) 'FLEXTRA error: Too many u,v grid points in z '//
     +'direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      endif

      if (nwz.gt.nwzmax) then                         
      write(*,*) 'FLEXTRA error: Too many w grid points in z '//
     +'direction.'
      write(*,*) 'Reduce resolution of wind fields (file GRIDSPEC).'
      error=.true.
      endif

 
C Compute often used help variables to convert geografical into grid coord.
***************************************************************************

      xthelp=180./pi/r_earth/dx
      ythelp=180./pi/r_earth/dy

 
C Compute grid distances in radians
***********************************

      dxradinv = 1./( dx * pi / 180. )
      dyradinv = 1./( dy * pi / 180. )


* CALCULATE VERTICAL DISCRETIZATION OF ECMWF MODEL
* PARAMETER akm,bkm DESCRIBE THE HYBRID "ETA" COORDINATE SYSTEM
* wheight(i) IS THE HEIGHT OF THE i-th MODEL HALF LEVEL (=INTERFACE BETWEEN
* 2 MODEL LEVELS) IN THE "ETA" SYSTEM

      numskip=nlev_ec-nuvz  ! number of ecmwf model layers not used
                            ! by trajectory model
      do 40 i=1,nwz
        j=numskip+i
        k=nlev_ec+1+numskip+i
        akm(nwz-i+1)=zsec2(10+j)
        bkm(nwz-i+1)=zsec2(10+k)
40      wheight(nwz-i+1)=akm(nwz-i+1)/p0+bkm(nwz-i+1)

* CALCULATION OF uvheight, akz, bkz
* akz,bkz ARE THE DISCRETIZATION PARAMETERS FOR THE MODEL LEVELS
* uvheight(i) IS THE HEIGHT OF THE i-th MODEL LEVEL IN THE "ETA" SYSTEM

      do 45 i=1,nuvz
         uvheight(i)=0.5*(wheight(i+1)+wheight(i))
         akz(i)=0.5*(akm(i+1)+akm(i))
         bkz(i)=0.5*(bkm(i+1)+bkm(i))
45    continue

C If vertical coordinates decrease with increasing altitude, multiply by -1.
C This means that also the vertical velocities have to be multiplied by -1.
****************************************************************************

      if (uvheight(1).lt.uvheight(nuvz)) then
        zdirect=1.
      else
        zdirect=-1.
        do 55 i=1,nuvz
55        uvheight(i)=zdirect*uvheight(i)
        do 65 i=1,nwz
65        wheight(i)=zdirect*wheight(i)
      endif


C Compute minimum and maximum height of modelling domain
********************************************************

      heightmin=max(uvheight(1),wheight(1))
      heightmax=min(uvheight(nuvz),wheight(nwz))


      return

999   write(*,*)  
      write(*,*) ' ###########################################'//
     &           '###### '
      write(*,*) '       TRAJECTORY MODEL SUBROUTINE GRIDCHECK:'
      write(*,*) ' CAN NOT OPEN INPUT DATA FILE '//wfname(ifn)
      write(*,*) ' ###########################################'//
     &           '###### '
      write(*,*)
      write(*,'(a)') '!!! PLEASE INSERT A NEW CD-ROM AND   !!!'
      write(*,'(a)') '!!! PRESS ANY KEY TO CONTINUE...     !!!'
      write(*,'(a)') '!!! ...OR TERMINATE FLEXTRA PRESSING !!!'
      write(*,'(a)') '!!! THE "X" KEY...                   !!!'
      write(*,*)
      read(*,'(a)') opt
      if(opt.eq.'X') then
        error=.true.
      else
        goto 5
      endif

      return
      end
