      subroutine inter3d(xt,yt,zt,index,itime,init,firststep,
     +iter,lkindz,dxdt,dydt,dzdt,indwz)
C                        i  i  i    i     i    i       i
C      i     i     o    o    o     o
********************************************************************************
*                                                                              *
*     Interpolation routine for 3-dimensional trajectories.                    *
*                                                                              *
*     Author: A. Stohl                                                         *
*                                                                              *
*     27 April 1994                                                            *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* dxdt,dydt,dzdt     wind components in grid units per second                  *
* firstep            .true. for first iteration of petterssen                  *
* idiff [s]          Temporal distance between the windfields used for interpol*
* indwz              index of the model layer beneath current position of traj.*
* init               .true. for first time step of trajectory                  *
* iter               number of time iteration step                             *
* itime [s]          current temporal position                                 *
* memtime(3) [s]     times for the wind fields in memory                       *
* nstop              =greater 0, if trajectory calculation is finished         *
* uint,vint,wint [m/s] interpolated wind components                            *
* xt,yt,zt           coordinates position for which wind data shall be calculat*
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      integer i,itime,index,indwz,iter,lkindz
      real xt,yt,zt,dxdt,dydt,dzdt,uint,vint,wint,psint,eta
      logical firststep,init



C Calculate the surface pressure.
*********************************

      call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +xt,yt,1,memtime(index),memtime(index+1),itime,index,psint)


C For a new trajectory and the first iteration of petterssen:
C Transformation from height in [m] coordinate to height in eta coordinate.
C Or: transformation from height in [Pa] to height in eta coordinate.
***************************************************************************

      if (init.and.firststep) then
        if ((lkindz.eq.1).or.(lkindz.eq.2)) then
        call etatrafo(xt,yt,zt,memtime(index),memtime(index+1),itime,
     +  index,psint)
        else if (lkindz.eq.3) then
        zt=eta(psint,zt)
        endif
      endif


C Calculate index of (w) layers between the trajectory point is situated.
C Trajectory point is located between wheight(indwz) and wheight(indwz+1)
*************************************************************************

      do 95 i=2,nwz
        if (wheight(i).ge.zt) goto 96
95      continue
96    indwz=i-1



C Interpolation of wind field data is done.
*******************************************

      if ((inpolkind.eq.1).and.(iter.ne.1)) then
        call interpol(uu,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     +  xt,yt,zt,memtime(index),memtime(index+1),itime,index,uint)
        call interpol(vv,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     +  xt,yt,zt,memtime(index),memtime(index+1),itime,index,vint)
        call interpol(ww,nxmax,nymax,nwzmax,nx,ny,nwz,memind,wheight,
     +  xt,yt,zt,memtime(index),memtime(index+1),itime,index,wint)
      else                               ! bilinear interpolation
        call lininterpol(uu,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,
     +  uvheight,xt,yt,zt,memtime(index),memtime(index+1),itime,index,
     +  uint)
        call lininterpol(vv,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,
     +  uvheight,xt,yt,zt,memtime(index),memtime(index+1),itime,index,
     +  vint)
        call lininterpol(ww,nxmax,nymax,nwzmax,nx,ny,nwz,memind,
     +  wheight,xt,yt,zt,memtime(index),memtime(index+1),itime,index,
     +  wint)
      endif


C TRANSFORMATION m/s --> grid units/time unit
*********************************************

      call utransform(uint,yt,dxdt)
      call vtransform(vint,dydt)
      call wtransform(wint,psint,zt,indwz,dzdt)
      
      return
      end
