      subroutine interisobar(xt,yt,zt,pconst,index,itime,init,firststep,
     +iter,lkindz,dxdt,dydt)
C                            i  i  i/o  i      i     i    i      i
C      i     i     o    o
********************************************************************************
*                                                                              *
*     Interpolation routine for isobaric trajectories.                         *
*                                                                              *
*     Author: A. Stohl                                                         *
*                                                                              *
*     27 April 1994                                                            *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* dxdt,dydt          wind components in grid units per second                  *
* eta                eta coordinate of pressure level                          *
* firststep          .true. for first iteration of petterssen                  *
* idiff [s]          Temporal distance between the windfields used for interpol*
* init               .true. for first time step of trajectory                  *
* iter               number of iteration step                                  *
* itime [s]          current temporal position                                 *
* lkindz             unit of z coordinate (1:masl, 2:magl, 3:hPa)              *
* memtime(3) [s]     times of the wind fields in memory                        *
* nstop              =greater 0, if trajectory calculation is finished         *
* pconst [Pa]        pressure level, for which trajectories shall be calculated*
* uint,vint [m/s]    interpolated wind components                              *
* xt,yt,zt           coordinates position for which wind data shall be calculat*
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      integer itime,index,iter,lkindz
      real xt,yt,zt,dxdt,dydt,uint,vint,psint,eta,pconst,pp
      logical init,firststep



C For a new trajectory and the first iteration of petterssen:
C Transformation from height in [m] coordinate to height in eta coordinate.
C Or: Transformation from hPa to eta.
C For this it is necessary to know the surface pressure.
***************************************************************************

      if (init.and.firststep) then
        call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +  xt,yt,1,memtime(index),memtime(index+1),itime,index,psint)
        if ((lkindz.eq.1).or.(lkindz.eq.2)) then
        call etatrafo(xt,yt,zt,memtime(index),memtime(index+1),itime,
     +  index,psint)
        pconst=pp(psint,zt)
        else if (lkindz.eq.3) then
        zt=eta(psint,zt)
        endif
      endif


C Transformation from height in pressure coordinate to height in eta coordinate.
C For this it is necessary to know the surface pressure.
*********************************************************************************

      call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +xt,yt,1,memtime(index),memtime(index+1),itime,index,psint)
      zt=eta(psint,pconst)


C Interpolation of wind field data is done.
*****************************************************************************

      if ((inpolkind.eq.1).and.(iter.ne.1)) then
        call interpol(uu,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     +  xt,yt,zt,memtime(index),memtime(index+1),itime,index,uint)
        call interpol(vv,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,uvheight,
     +  xt,yt,zt,memtime(index),memtime(index+1),itime,index,vint)
      else                               ! bilinear interpolation
        call lininterpol(uu,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,
     +  uvheight,xt,yt,zt,memtime(index),memtime(index+1),itime,index,
     +  uint)
        call lininterpol(vv,nxmax,nymax,nuvzmax,nx,ny,nuvz,memind,
     +  uvheight,xt,yt,zt,memtime(index),memtime(index+1),itime,index,
     +  vint)
      endif


C TRANSFORMATION m/s --> grid units/time unit
*********************************************

      call utransform(uint,yt,dxdt)
      call vtransform(vint,dydt)

      return
      end
