      subroutine intermix(xt,yt,zt,zconst,index,itime,iter,dxdt,dydt)
C                         i  i  i    i      i     i    i    o    o
********************************************************************************
*                                                                              *
*     Interpolation routine for mixing layer trajectories.                     *
*                                                                              *
*     Author: A. Stohl                                                         *
*                                                                              *
*     27 April 1994                                                            *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* dxdt,dydt          wind components in grid units per second                  *
* firstep            .true. for first iteration of petterssen                  *
* hmix               height of mixing layer in eta coordinates                 *
* idiff [s]          Temporal distance between the windfields used for interpol*
* induvz             index of the model layer beneath current position of traj.*
* init               .true. for first time step of trajectory                  *
* iter               number of iteration step                                  *
* itime [s]          current temporal position                                 *
* memtime(3) [s]     times of the wind fields in memory                        *
* pp [Pa]            pressure at mixing height                                 *
* nstop              =greater 0, if trajectory calculation is finished         *
* uint,vint [m/s]    interpolated wind components                              *
* xt,yt,zt           coordinates position for which wind data shall be calculat*
* zconst [m]         height of mixing layer                                    *
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      integer i,itime,index,induvz,iter
      real xt,yt,zt,zconst,dxdt,dydt,uint,vint,uhelp,vhelp,psint
      real hmix,weight,pp,ph1,ph2


C Transformation from mixing height in [m] coordinate to height in eta coordinate.
C For this it is necessary to know the surface pressure.
**********************************************************************************

      call levlininterpol(ps,nxmax,nymax,1,nx,ny,memind,
     +xt,yt,1,memtime(index),memtime(index+1),itime,index,psint)
      hmix=zconst
      call etatrafo(xt,yt,hmix,memtime(index),memtime(index+1),itime,
     +index,psint)


C Calculate the index of layers between the mixed layer height is situated.
***************************************************************************

      do 85 induvz=1,nuvz-1
        if (uvheight(induvz).ge.hmix) goto 86
85      continue
86    continue

C Mixed layer height is located between uvheight(induvz-1) and uvheight(induvz)
*******************************************************************************

C 1.) If mixed layer height is lower than the first model level
C     -> take wind data from first model level
***************************************************************

      if (induvz.eq.1) then
        zt=uvheight(1)
        if ((inpolkind.eq.1).and.(iter.ne.1)) then
          call levinterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,1,memtime(index),memtime(index+1),itime,
     +    index,uint)
          call levinterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,1,memtime(index),memtime(index+1),itime,
     +    index,vint)
        else                               ! linear interpolation
          call levlininterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,1,memtime(index),memtime(index+1),itime,
     +    index,uint)
          call levlininterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,1,memtime(index),memtime(index+1),itime,
     +    index,vint)
        endif


C 2.) Normal case: mixed layer higher than the first model level
C     -> take average wind within mixed layer for trajectory displacement
*************************************************************************

      else
        weight=0.
        uhelp=0.
        vhelp=0.
        ph1=psint

        do 140 i=1,induvz-2

C Interpolation of wind field data is done.
C -> Interpolated winds are weighted with the thicknesses of the layers
***********************************************************************

          if ((inpolkind.eq.1).and.(iter.ne.1)) then
            call levinterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +      xt,yt,i,memtime(index),memtime(index+1),itime,
     +      index,uint)
            call levinterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +      xt,yt,i,memtime(index),memtime(index+1),itime,
     +      index,vint)
          else                               ! bilinear interpolation
            call levlininterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +      xt,yt,i,memtime(index),memtime(index+1),itime,
     +      index,uint)
            call levlininterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +      xt,yt,i,memtime(index),memtime(index+1),itime,
     +      index,vint)
          endif
          ph2=akm(i+1)+bkm(i+1)*psint
          weight=weight+ph1-ph2
          uhelp=uhelp+uint*(ph1-ph2)
          vhelp=vhelp+vint*(ph1-ph2)
140       ph1=ph2


        if ((inpolkind.eq.1).and.(iter.ne.1)) then
          call levinterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,induvz-1,memtime(index),memtime(index+1),itime,
     +    index,uint)
          call levinterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,induvz-1,memtime(index),memtime(index+1),itime,
     +    index,vint)
        else                               ! bilinear interpolation
          call levlininterpol(uu,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,induvz-1,memtime(index),memtime(index+1),itime,
     +    index,uint)
          call levlininterpol(vv,nxmax,nymax,nuvzmax,nx,ny,memind,
     +    xt,yt,induvz-1,memtime(index),memtime(index+1),itime,
     +    index,vint)
        endif
        ph2=pp(psint,hmix)
        weight=weight+ph1-ph2
        uhelp=uhelp+uint*(ph1-ph2)
        vhelp=vhelp+vint*(ph1-ph2)

        uint=uhelp/weight
        vint=vhelp/weight
      endif

C TRANSFORMATION m/s --> grid units/time unit
*********************************************

      call utransform(uint,yt,dxdt)
      call vtransform(vint,dydt)
      zt=hmix

      return
      end
