      subroutine readcommand(error)
C                              o
********************************************************************************
*                                                                              *
*     This routine reads the user specifications for the current model run.    *
*                                                                              *
*     Authors: A. Stohl                                                        *
*                                                                              *
*     2 February 1994                                                          *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* bdate                beginning date as Julian date                           *
* edate                ending date as Julian date                              *
* error                .true., if error ocurred in subprogram, else .false.    *
* hhh                  hour                                                    *
* ibdate,ibtime        beginnning date and time (YYYYMMDD, HHMISS)             *
* ideltas [s]          modelling period                                        *
* iedate,ietime        ending date and time (YYYYMMDD, HHMISS)                 *
* interv [s]           interval between two trajectory calculations            *
* ischeme              kind of integration scheme for trajectories (1 or 2)    *
* ldirect              -1 for backward, 1 for forward trajectories             *
* lentra [s]           length of one trajectory                                *
* ldim                 number of steps along the interpolated trajectory       *
* mi                   minute                                                  *
* ss                   second                                                  *
*                                                                              *
* Constants:                                                                   *
* unitcommand          unit connected to file COMMAND                          *
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      logical error
      integer i,hhh,mi,ss
      double precision edate,juldate


C Open the command file and read user options
*********************************************

      error=.false.

      open(unitcommand,file=path(1)(1:len(1))//'COMMAND',status='old',
     +err=999)

      do 10 i=1,7
10      read(unitcommand,*)
      read(unitcommand,'(3x,i2)') ldirect
      do 20 i=1,3
20      read(unitcommand,*)
      read(unitcommand,'(3x,i7)') lentra
      do 30 i=1,3
30      read(unitcommand,*)
      read(unitcommand,'(3x,i8,1x,i6)') ibdate,ibtime
      do 40 i=1,3
40      read(unitcommand,*)
      read(unitcommand,'(3x,i8,1x,i6)') iedate,ietime
      do 50 i=1,3
50      read(unitcommand,*)
      read(unitcommand,'(3x,i7)') interv         
      do 60 i=1,3
60      read(unitcommand,*)
      read(unitcommand,'(3x,i1,2x,i5)') inter,interstep
      do 70 i=1,3
70      read(unitcommand,*)
      read(unitcommand,'(3x,i5,2x,f7.3,3(2x,f5.3))') numbunc,distunc,
     +epsu,epsv,epsw
      do 80 i=1,3
80      read(unitcommand,*)
      read(unitcommand,'(3x,i1)') ischeme
      do 90 i=1,3
90     read(unitcommand,*)
      read(unitcommand,'(3x,i1)') inpolkind
      do 100 i=1,3
100     read(unitcommand,*)
      read(unitcommand,'(4x,f6.2)') cfl
      do 110 i=1,3
110     read(unitcommand,*)
      read(unitcommand,'(4x,f6.2)') cflt
      
      close(unitcommand)


C Check input dates
*******************

      if (iedate.lt.ibdate) then
        write(*,*) ' #### TRAJECTORY MODEL ERROR! BEGINNING DATE  #### ' 
        write(*,*) ' #### IS LARGER THAN ENDING DATE. CHANGE      #### '
        write(*,*) ' #### EITHER POINT 3 OR POINT 4 IN FILE       #### '
        write(*,*) ' #### "COMMAND".                              #### '
        error=.true.
        return
      else if (iedate.eq.ibdate) then
        if (ietime.lt.ibtime) then
        write(*,*) ' #### TRAJECTORY MODEL ERROR! BEGINNING TIME  #### ' 
        write(*,*) ' #### IS LARGER THAN ENDING TIME. CHANGE      #### '
        write(*,*) ' #### EITHER POINT 3 OR POINT 4 IN FILE       #### '
        write(*,*) ' #### "COMMAND".                              #### '
        error=.true.
        return

        endif
      endif


C Check kind of integration scheme
**********************************

      if ((ischeme.ne.1).and.(ischeme.ne.2)) then
        write(*,*) ' #### TRAJECTORY MODEL ERROR! FILE "COMMAND": #### ' 
        write(*,*) ' #### SCHEME MUST BE EITHER 1 OR 2.           #### '
        error=.true.
        return
      endif

C Check CFL criterions
**********************

      if((cfl.lt.1.).or.(cflt.lt.1.)) then
        write(*,*) ' #### TRAJECTORY MODEL ERROR! CFL CRITERION   #### ' 
        write(*,*) ' #### MUST NOT BE SET LESS THEN 1 !!!         #### '
        error=.true.
        return
      endif


C Conversion of format HHHMISS to seconds
*****************************************

      hhh=lentra/10000
      mi=(lentra-10000*hhh)/100
      ss=lentra-10000*hhh-100*mi
      lentra=ldirect*(hhh*3600+60*mi+ss)

      hhh=interv/10000
      mi=(interv-10000*hhh)/100
      ss=interv-10000*hhh-100*mi
      interv=hhh*3600+60*mi+ss


C Compute number of time steps along interpolated trajectory
************************************************************

      if (interstep.lt.1) interstep=1
      ldim=ldirect*lentra/interstep+1

      if ((inter.ge.0).and.(ldim.gt.maxitime)) then
        write(*,*) ' #### TRAJECTORY MODEL ERROR! INTERPOLATION   #### ' 
        write(*,*) ' #### TO SUCH A SHORT TIME STEP IS NOT        #### '
        write(*,*) ' #### POSSIBLE. SET SSSSS IN POINT 7. OF FILE #### '
        write(*,*) ' #### "COMMAND" TO A GREATER VALUE.           #### '
        error=.true.
        return
      endif

C Compute modelling time in seconds and beginning date in Julian date
*********************************************************************

      if (ldirect.eq.1) then
        bdate=juldate(ibdate,ibtime)
        edate=juldate(iedate,ietime)
        ideltas=nint(86400.*(edate-bdate))+lentra
      else if (ldirect.eq.-1) then
        bdate=juldate(iedate,ietime)
        edate=juldate(ibdate,ibtime)
        ideltas=nint(86400.*(edate-bdate))+lentra
      else
        write(*,*) ' #### TRAJECTORY MODEL ERROR! DIRECTION IN    #### ' 
        write(*,*) ' #### FILE "COMMAND" MUST BE EITHER -1 OR 1.  #### '
        error=.true.
        return
      endif


      return    

999   write(*,*) ' #### TRAJECTORY MODEL ERROR! FILE "COMMAND"  #### ' 
      write(*,*) ' #### CANNOT BE OPENED IN THE DIRECTORY       #### '
      write(*,*) ' #### xxx/trajec/options                      #### '
      error=.true.

      return
      end
