      subroutine readwind(indj,n)
***********************************************************************
*                                                                     * 
*             TRAJECTORY MODEL SUBROUTINE READWIND                    *
*                                                                     *
***********************************************************************
*                                                                     * 
*             AUTHOR:      G. WOTAWA                                  *
*             DATE:        1997-08-05                                 *
*             LAST UPDATE: ----------                                 *
*                                                                     * 
***********************************************************************
*                                                                     *
* DESCRIPTION:                                                        *
*                                                                     *
* READING OF ECMWF METEOROLOGICAL FIELDS FROM INPUT DATA FILES. THE   *
* INPUT DATA FILES ARE EXPECTED TO BE AVAILABLE IN GRIB CODE          *
*                                                                     *
* INPUT:                                                              *
* indj               indicates number of the wind field to be read in *
* n                  temporal index for meteorological fields (1 to 3)*
*                                                                     *
* IMPORTANT VARIABLES FROM COMMON BLOCK:                              *
*                                                                     *
* wfname             File name of data to be read in                  *
* nx,ny,nuvz,nwz     expected field dimensions                        *
* nlev_ec            number of vertical levels ecmwf model            *
* uu,vv,ww           wind fields                                      *
* tt,qv              temperature and specific humidity                *
* ps                 surface pressure                                 *
*                                                                     *
***********************************************************************
*

      include 'includepar'
      include 'includecom'
      integer indj,i,j,k,n,levdiff1,levdiff2,ifield,iumax,iwmax

* VARIABLES AND ARRAYS NEEDED FOR GRIB DECODING

      integer isec0(2),isec1(56),isec2(512),isec3(2),isec4(64)
      integer inbuff(jpack),ilen,ierr,lunit,iword
      real zsec2(128),zsec3(2),zsec4(jpunp),xhelp,yhelp,xhelp0,yhelp0
      character*1 yoper,opt
      logical error

      data yoper/'D'/

      levdiff1=nlev_ec-nuvz+1
      levdiff2=nlev_ec-nwz+1
      iumax=0
      iwmax=0
*
* OPENING OF DATA FILE (GRIB CODE)
*
5     call pbopen_(lunit,path(2)(1:len(2))//wfname(indj),'r',ierr)
      if(ierr.lt.0) goto 999

      ifield=0
10    ifield=ifield+1
*
* GET NEXT FIELDS
*
      call pbgrib(lunit,inbuff,jpack,ilen,ierr)
      if(ierr.eq.-1) goto 50    ! EOF DETECTED
      if(ierr.lt.-1) goto 888   ! ERROR DETECTED

      ierr=1
      call gribex(isec0,isec1,isec2,zsec2,isec3,zsec3,isec4,
     &            zsec4,jpunp,inbuff,jpack,iword,yoper,ierr)
      if (ierr.ne.0) goto 888   ! ERROR DETECTED

      if(ifield.eq.1) then

* CHECK GRID SPECIFICATIONS

        if(isec2(2).ne.nx) stop 'READWIND: NX NOT CONSISTENT'
        if(isec2(3).ne.ny) stop 'READWIND: NY NOT CONSISTENT'
        if(isec2(12)/2-1.ne.nlev_ec)
     &    stop 'READWIND: VERTICAL DISCRETIZATION NOT CONSISTENT'
        xhelp=float(isec2(5))/1000.
        yhelp=float(isec2(7))/1000.
        xhelp0=xlon0
        yhelp0=xlat0
        if(xhelp.lt.0.) xhelp=xhelp+360.
        if(yhelp.lt.0.) yhelp=yhelp+360.
        if(xhelp0.lt.0.) xhelp0=xhelp0+360.
        if(yhelp0.lt.0.) yhelp0=yhelp0+360.
        if(xhelp.ne.xhelp0)
     &    stop 'READWIND: LOWER LEFT LONGITUDE NOT CONSISTENT'
        if(yhelp.ne.yhelp0)
     &    stop 'READWIND: LOWER LEFT LATITUDE NOT CONSISTENT'
      endif

      do 20 i=0,nx-1
        do 20 j=0,ny-1
          k=isec1(8)
          if(isec1(6).eq.130) tt(i,j,nlev_ec-k+1,n)=    !! TEMPERATURE
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.131) uu(i,j,nlev_ec-k+1,n)=    !! U VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.132) vv(i,j,nlev_ec-k+1,n)=    !! V VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.134) ps(i,j,1,n)=              !! SURF. PRESS.
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.135) ww(i,j,nlev_ec-k+1,n)=    !! W VELOCITY
     &                        zsec4(nx*(ny-j-1)+i+1)
          if(isec1(6).eq.129) oro(i,j)=                 !! ECMWF OROGRAPHY
     &                        zsec4(nx*(ny-j-1)+i+1)/ga
          if(isec1(6).eq.131) iumax=max(iumax,nlev_ec-k+1)
          if(isec1(6).eq.135) iwmax=max(iwmax,nlev_ec-k+1)
20    continue

      goto 10                      !! READ NEXT LEVEL OR PARAMETER
*
* CLOSING OF INPUT DATA FILE
*
50    call pbclose_(lunit,ierr)     !! FINNISHED READING / CLOSING GRIB FILE

      if(levdiff2.eq.0) then
        iwmax=nlev_ec+1
        do 60 i=0,nx-1
          do 60 j=0,ny-1
60          ww(i,j,nlev_ec+1,n)=0.
      endif

      if(iumax.ne.nuvz) stop 'READWIND: NUVZ NOT CONSISTENT'
      if(iwmax.ne.nwz)  stop 'READWIND: NWZ NOT CONSISTENT'

      return    
888   write(*,*) ' #### TRAJECTORY MODEL ERROR! WINDFIELD       #### ' 
      write(*,*) ' #### ',wfname(indj),'                    #### '
      write(*,*) ' #### IS NOT GRIB FORMAT !!!                  #### '
      stop 'Execution terminated'

999   write(*,*) ' #### TRAJECTORY MODEL ERROR! WINDFIELD       #### ' 
      write(*,*) ' #### ',wfname(indj),'                    #### '
      write(*,*) ' #### CANNOT BE OPENED !!!                    #### '
      write(*,*)
      write(*,'(a)') '!!! PLEASE INSERT A NEW CD-ROM AND   !!!'
      write(*,'(a)') '!!! PRESS ANY KEY TO CONTINUE...     !!!'
      write(*,'(a)') '!!! ...OR TERMINATE FLEXTRA PRESSING !!!'
      write(*,'(a)') '!!! THE "X" KEY...                   !!!'
      write(*,'(a)') '!!! PLEASE CHECK CD-ROM LABEL AND    !!!'
      write(*,'(a)') '!!! CORRECT FILE "PATHNAMES"...      !!!'
      write(*,*)
      read(*,'(a)') opt
      if(opt.eq.'X') then
        stop 'Execution terminated'
      else
        call readpaths(error)
        if(error)
     &    stop 'Error reading "pathnames" --> execution terminated'
        goto 5
      endif

      end
