      subroutine trajout(numb,nstop)          
C                         i     i
********************************************************************************
*                                                                              *
*     This routine writes the output files.                                    *
*                                                                              *
*     Authors: A. Stohl                                                        *
*                                                                              *
*     2 February 1994                                                          *
*                                                                              *
********************************************************************************
*                                                                              *
* Variables:                                                                   *
* bdate                 beginning date of modelling period                     *
*                                                                              *
* idate,itime           date and time,help variables                           *
* inter                 output with flexible (0,2) or constant time step (1,2) *
* ldim                  number of interpolated time steps                      *
* npoint(maxtra)        number of starting point for each trajectory           *
* nstop                 error code                                             *
* nttra(maxtra)         number of time steps along the trajectory              *
* numb                  number of trajectory to be written to output file      *
* juldate               Julian starting date of trajectory                     *
* xtra,ytra,ztra(maxtra,maxtime)     grid coordinates of trajectory (flexible) *
* xtraint,ytraint,ztraint(maxitime)  grid coordinates of trajectory (flexible) *
*                                                                              *
* Constants:                                                                   *
*                                                                              *
********************************************************************************

      include 'includepar'
      include 'includecom'

      integer nstop,numb,idate,itime,i,ldimi
      real ortra(maxtime),ortraint(maxitime)
      double precision juldate


C If serious error has occurred, reduce the number of time steps by 1.
C This has to be done to exclude unrealistic values.
**********************************************************************

      if (nstop.gt.1) nttra(numb)=nttra(numb)-1


C Add the height of the orography to give height above sea level
****************************************************************

      do 10 i=1,nttra(numb)
        call orolininterpol(oro,nxmax,nymax,nx,ny,xtra(numb,i),
     +  ytra(numb,i),ortra(i))
10    htra(numb,i)=htra(numb,i)+ortra(i)


C Conversion of grid coordinates to geografical coordinates
***********************************************************

      do 30 i=1,nttra(numb)
        call lamphi_ecmwf(xtra(numb,i),ytra(numb,i),xtra(numb,i),
     +  ytra(numb,i))
30      ptra(numb,i)=ptra(numb,i)/100.          ! conversion Pa -> hPa


C If trajectory information is wanted with constant time step, interpolate the
C trajectory to constant time step
******************************************************************************

      if (inter.ge.1) then
        call trajinterpol(numb,ldimi,ortra,ortraint)
      endif


C Calculate starting date and time of trajectory
************************************************

      juldate=bdate+dble(float(ittra(numb,1)))/86400.
      call caldate(juldate,idate,itime)


C Output of trajectories with flexible time step
************************************************

      if ((inter.eq.0).or.(inter.eq.2)) then
        if (nttra(numb).eq.1) nttra(numb)=0
        write(unittraj+npoint(numb),'(a6,i8,a9,i8,a16,i1,a16,i5)') 
     +  'DATE: ',idate,'    TIME:',itime,'    STOP INDEX: ',nstop,
     +  '    # OF POINTS:',nttra(numb)
        write(unittraj+npoint(numb),67) '    SECS',
     +  '   LONGIT','   LATIT','    ETA','  PRESS','     Z',' Z-ORO',
     +'     PV',' THETA'
        do 40 i=1,nttra(numb)
40        write(unittraj+npoint(numb),66) 
     +    ittra(numb,i)-ittra(numb,1),xtra(numb,i),ytra(numb,i),
     +    ztra(numb,i)*zdirect,ptra(numb,i),htra(numb,i),
     +    htra(numb,i)-ortra(i),vorttra(numb,i),pottem(numb,i)
      endif


C Output of trajectories with constant time step
************************************************

      if (inter.ge.1) then                         
        if (ldimi.eq.1) ldimi=0
        write(unittraji+npoint(numb),'(a6,i8,a9,i8,a16,i1,a16,i5)') 
     +  'DATE: ',idate,'    TIME:',itime,'    STOP INDEX: ',nstop,
     +  '    # OF POINTS:',ldimi
        write(unittraji+npoint(numb),67) '    SECS',
     +  '   LONGIT','   LATIT','    ETA','  PRESS','     Z',' Z-ORO',
     +'     PV',' THETA'
        do 50 i=1,ldimi
50        write(unittraji+npoint(numb),66) 
     +    ittraint(i)-ittraint(1),xtraint(i),ytraint(i),ztraint(i)*
     +    zdirect,ptraint(i),htraint(i),htraint(i)-ortraint(i),
     +    vorttraint(i),pottemint(i)
      endif

66    format(i8,2f9.4,1x,f6.4,f7.1,2f6.0,f7.3,f6.1)
67    format(a8,a9,a9,a7,a7,a6,a6,a7,a6)

      return    
      end
